@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2013 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2015 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -9,6 +9,209 @@
 
 
 
+
+
+
+subsetcol <-
+Select <-
+  function(
+           data = list(),
+           prefix = "y",
+
+           lhs  = NULL,
+           rhs  = NULL,  # Can be "0" to suppress an intercept, else "".
+           rhs2 = NULL,  # Can be "0" to suppress an intercept, else "".
+           rhs3 = NULL,  # Can be "0" to suppress an intercept, else "".
+
+           as.character = FALSE,
+           as.formula.arg = FALSE,
+           tilde = TRUE,
+           exclude = NULL,
+           sort.arg = TRUE) {
+
+
+
+
+
+  if (is.character(exclude))
+    if (any(nchar(prefix) == 0))
+      stop("bad input for argument 'exclude'")
+  if (!is.logical(sort.arg) || 
+      length(sort.arg) != 1)
+    stop("bad input for argument 'sort.arg'")
+
+
+  col.names <- colnames(data)
+  if (is.logical(prefix)) {
+    index <- if (prefix) 1:length(col.names) else
+             stop("cannot have 'prefix = FALSE'")
+  } else {
+    index <- NULL
+    for (ii in 1:length(prefix)) {
+      small.col.names <- substr(col.names, 1, nchar(prefix[ii]))
+
+      index <- c(index, grep(prefix[ii], small.col.names))
+    }
+  }
+
+
+
+
+
+  temp.col.names <- col.names[index]
+
+
+  if (length(exclude)) {
+    exclude.index <- NULL
+    for (ii in 1:length(exclude)) {
+      exclude.index <- c(exclude.index,
+                         (1:length(col.names))[exclude[ii] == col.names])
+    }
+    exclude.index <- unique(sort(exclude.index))
+    index <- setdiff(index, exclude.index)
+    temp.col.names <- col.names[index]
+  }
+
+
+
+
+  if (sort.arg) {
+    ooo <- order(temp.col.names)
+    index <- index[ooo]
+    temp.col.names <- temp.col.names[ooo]
+  }
+
+
+
+ ltcn.positive <- (length(temp.col.names) > 0)
+
+
+
+  if (as.formula.arg) {
+    form.string <- paste0(ifelse(length(lhs), lhs, ""),
+                          ifelse(tilde, " ~ ", ""),
+                          if (ltcn.positive)
+                            paste(temp.col.names, collapse = " + ") else
+                            "",
+                          ifelse(ltcn.positive && length(rhs ), " + ", ""),
+                          ifelse(length(rhs ), rhs, ""),
+                          ifelse(length(rhs2), paste(" +", rhs2), ""),
+                          ifelse(length(rhs3), paste(" +", rhs3), ""))
+
+    if (as.character) {
+      form.string
+    } else {
+      as.formula(form.string)
+    }
+  } else {
+    if (as.character) {
+      paste0("cbind(",
+             paste(temp.col.names, collapse = ", "),
+             ")")
+    } else {
+      ans <- if (is.matrix(data)) data[, index] else
+             if (is.list(data)) data[index] else
+             stop("argument 'data' is neither a list or a matrix")
+      if (length(ans)) {
+        as.matrix(ans)
+      } else {
+        NULL
+      }
+    }
+  }
+}
+
+
+
+
+
+
+
+
+if (FALSE)
+subsetc <-
+  function(x, select,
+           prefix = NULL,
+           subset = TRUE, drop = FALSE,
+           exclude = NULL,
+           sort.arg = !is.null(prefix),
+           as.character = FALSE) {
+
+  if (!is.null(prefix)) {
+    if (!missing(select))
+      warning("overwriting argument 'select' by something ",
+              "using 'prefix'")
+    select <- grepl(paste0("^", prefix), colnames(x))
+  }
+
+  if (missing(select)) {
+    vars <- TRUE
+  } else {
+    nl <- as.list(seq_along(x))  # as.list(1L:ncol(x))
+    names(nl) <- names(x)  # colnames(x)
+    vars <- eval(substitute(select), nl, parent.frame())
+  }
+
+  ans <- x[subset & !is.na(subset), vars, drop = drop]
+  if (sort.arg) {
+    cna <- colnames(ans)
+    ooo <- order(cna)
+    ans <- ans[, ooo, drop = drop]
+  }
+
+  if (!is.null(exclude)) {
+    cna <- colnames(ans)
+    ooo <- match(exclude, cna)
+    ans <- ans[, -ooo, drop = drop]
+  }
+
+  if (as.character) {
+    cna <- colnames(ans)
+    paste0("cbind(", paste0(cna, collapse = ", "), ")")
+  } else {
+    ans
+  }
+}
+
+
+
+
+
+
+
+ grid.search <- function(vov, objfun, y, x, w, extraargs = NULL,
+                         maximize = TRUE, abs.arg = FALSE,
+                         ret.objfun = FALSE, ...) {
+  if (!is.vector(vov))
+    stop("argument 'vov' must be a vector")
+  objvals <- vov
+  for (ii in 1:length(vov))
+    objvals[ii] <- objfun(vov[ii], y = y, x = x, w = w,
+                          extraargs = extraargs, ...)
+  try.this <- if (abs.arg) {
+               if (maximize) vov[abs(objvals) == max(abs(objvals))] else
+               vov[abs(objvals) == min(abs(objvals))]
+             } else {
+               if (maximize) vov[objvals == max(objvals)] else
+               vov[objvals == min(objvals)]
+             }
+  if (!length(try.this))
+    stop("something has gone wrong!")
+  ans <- if (length(try.this) == 1)
+    try.this else sample(try.this, size = 1)
+
+
+  myvec <- objvals[ans == vov]  # Could be a vector
+  if (ret.objfun) c(Value = ans, ObjFun = myvec[1]) else ans
+}
+
+
+
+
+
+
+
+
  getind <- function(constraints, M, ncolx) {
 
 
@@ -21,7 +224,7 @@
   }
 
   ans <- vector("list", M+1)
-  names(ans) <- c(paste("eta", 1:M, sep = ""), "ncolX_vlm")
+  names(ans) <- c(paste("eta", 1:M, sep = ""), "ncolX.vlm")
 
   temp2 <- matrix(unlist(constraints), nrow = M)
   for (kk in 1:M) {
@@ -34,7 +237,7 @@
       }
     }
     ans[[kk]] <- list(xindex = ansx,
-                  X_vlmindex = (1:ncol(temp2))[temp2[kk,] != 0])
+                  X.vlmindex = (1:ncol(temp2))[temp2[kk,] != 0])
   }
   ans[[M+1]] <- ncol(temp2)
 
@@ -43,11 +246,13 @@
 
 
 
- cm.vgam <- function(cm, x, bool, constraints,
-                     apply.int = FALSE, overwrite = FALSE,
-                     cm.default = diag(nrow(cm)),  # 20121226
-                     cm.intercept.default = diag(nrow(cm))  # 20121226
-                    ) {
+
+ cm.VGAM <-
+  function(cm, x, bool, constraints,
+           apply.int = FALSE, 
+           cm.default = diag(nrow(cm)),  # 20121226
+           cm.intercept.default = diag(nrow(cm))  # 20121226
+          ) {
 
 
 
@@ -59,7 +264,7 @@
     stop("argument 'cm' is not a matrix")
   M <- nrow(cm)
   asgn <- attr(x, "assign")
-  if(is.null(asgn))
+  if (is.null(asgn))
     stop("the 'assign' attribute is missing from 'x'; this ",
          "may be due to some missing values")  # 20100306
   nasgn <- names(asgn)
@@ -105,13 +310,26 @@
       return(constraints)
     }
   } else {
-      tbool <- terms(bool)
-      if (attr(tbool, "response")) {
-        ii <- attr(tbool, "factors")
-        default <- dimnames(ii)[[1]]
-        default <- default[1]
-        default <- parse(text = default[1])[[1]]
-        default <- as.logical(eval(default))
+    tbool <- terms(bool)
+    if (attr(tbool, "response")) {
+      ii <- attr(tbool, "factors")
+      default <- dimnames(ii)[[1]]
+      default <- default[1]
+      default <- if (is.null(default[1])) {
+        t.or.f <- attr(tbool, "variables")
+
+        t.or.f <- as.character( t.or.f )
+        if (t.or.f[1] == "list" && length(t.or.f) == 2 &&
+           (t.or.f[2] == "TRUE" || t.or.f[2] == "FALSE")) {
+          t.or.f <- as.character( t.or.f[2] )
+          parse(text = t.or.f)[[1]]
+        } else {
+          stop("something gone awry")
+        }
+      } else {
+        parse(text = default[1])[[1]]  # Original
+      }
+      default <- as.logical(eval(default))
     } else {
       default <- TRUE
     }
@@ -133,12 +351,12 @@
 
 
 
-cm.nointercept.vgam <- function(constraints, x, nointercept, M) {
+cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
 
   asgn <- attr(x, "assign")
   nasgn <- names(asgn)
   if (is.null(constraints)) {
-    constraints <- vector("list", length(nasgn)) # list()
+    constraints <- vector("list", length(nasgn))  # list()
     names(constraints) <- nasgn
   }
   if (!is.list(constraints))
@@ -173,7 +391,7 @@ cm.nointercept.vgam <- function(constraints, x, nointercept, M) {
 
 
 
- cm.zero.vgam <- function(constraints, x, zero, M) {
+ cm.zero.VGAM <- function(constraints, x, zero = NULL, M = 1) {
 
   asgn <- attr(x, "assign")
   nasgn <- names(asgn)
@@ -190,10 +408,11 @@ cm.nointercept.vgam <- function(constraints, x, nointercept, M) {
 
   if (is.null(zero))
     return(constraints)
+
   if (!is.numeric(zero))
-    stop("'zero' must be numeric")
+    stop("argument 'zero' must be numeric")
   if (any(zero < 1 | zero > M))
-    stop("'zero' out of range")
+    stop("argument 'zero' out of range")
   if (nasgn[1] != "(Intercept)")
     stop("cannot fit an intercept to a no-intercept model")
 
@@ -203,7 +422,7 @@ cm.nointercept.vgam <- function(constraints, x, nointercept, M) {
       Hmatk[zero, ] <- 0
       index <- NULL
       for (kk in 1:ncol(Hmatk))
-        if (all(Hmatk[,kk] == 0)) index <- c(index, kk)
+        if (all(Hmatk[, kk] == 0)) index <- c(index, kk)
       if (length(index) == ncol(Hmatk)) 
         stop("constraint matrix has no columns!")
       if (!is.null(index))
@@ -215,8 +434,14 @@ cm.nointercept.vgam <- function(constraints, x, nointercept, M) {
 
 
 
- process.constraints <- function(constraints, x, M,
-                                 by.col = TRUE, specialCM = NULL) {
+ process.constraints <-
+  function(constraints, x, M,
+           by.col = TRUE, specialCM = NULL,
+           Check.cm.rank = TRUE  # 20140626
+          ) {
+
+
+
 
 
 
@@ -232,46 +457,49 @@ cm.nointercept.vgam <- function(constraints, x, nointercept, M) {
   }
 
   if (is.matrix(constraints))
-      constraints <- list(constraints)
+    constraints <- list(constraints)
 
   if (!is.list(constraints))
-      stop("'constraints' must be a list")
+    stop("'constraints' must be a list")
 
   lenconstraints <- length(constraints)
   if (lenconstraints > 0)
     for (ii in 1:lenconstraints) {
-      constraints[[ii]] <- eval(constraints[[ii]])
+      list.elt <- constraints[[ii]]
+
+      if (is.function(list.elt)) {
+        list.elt <- list.elt()
+      }
+
+      constraints[[ii]] <- eval(list.elt)
       if (!is.null  (constraints[[ii]]) &&
           !is.matrix(constraints[[ii]]))
-          stop("'constraints[[", ii, "]]' is not a matrix")
+        stop("'constraints[[", ii, "]]' is not a matrix")
     }
 
   if (is.null(names(constraints))) 
     names(constraints) <- rep(nasgn, length.out = lenconstraints) 
 
-  temp <- if (!is.R()) list() else {
-    junk <- vector("list", length(nasgn))
-    names(junk) <- nasgn
-    junk
-  }
+  temp <- vector("list", length(nasgn))
+  names(temp) <- nasgn
   for (ii in 1:length(nasgn))
     temp[[nasgn[ii]]] <-
       if (is.null(constraints[[nasgn[ii]]])) diag(M) else
              eval(constraints[[nasgn[ii]]])
 
   for (ii in 1:length(asgn)) {
-      if (!is.matrix(temp[[ii]])) {
-        stop("not a constraint matrix")
-      }
-      if (ncol(temp[[ii]]) > M)
-        stop("constraint matrix has too many columns")
+    if (!is.matrix(temp[[ii]])) {
+      stop("not a constraint matrix")
+    }
+    if (ncol(temp[[ii]]) > M)
+      stop("constraint matrix has too many columns")
   }
 
   if (!by.col)
     return(temp)
 
   constraints <- temp
-  Blist <- vector("list", ncol(x))
+  Hlist <- vector("list", ncol(x))
   for (ii in 1:length(asgn)) {
     cols <- asgn[[ii]]
     ictr <- 0
@@ -281,43 +509,63 @@ cm.nointercept.vgam <- function(constraints, x, nointercept, M) {
                 any(nasgn[ii] == names(specialCM))) {
               slist <- specialCM[[(nasgn[ii])]]
               slist[[ictr]]
-            } else constraints[[ii]]
-      Blist[[jay]] <- cm 
+            } else {
+              constraints[[ii]]
+            }
+      Hlist[[jay]] <- cm 
     }
   }
-  names(Blist) <- dimnames(x)[[2]]
-  Blist
+  names(Hlist) <- dimnames(x)[[2]]
+
+
+
+  if (Check.cm.rank) {
+    all.svd.d <- function(x) svd(x)$d
+    mylist <- lapply(Hlist, all.svd.d)
+
+    if (max(unlist(lapply(mylist, length))) > M)
+      stop("some constraint matrices have more than ", M,
+           "columns")
+
+    MyVector <- unlist(mylist)
+    if (min(MyVector) < 1.0e-10)
+      stop("some constraint matrices are not of ",
+           "full column-rank: ",
+           paste(names(MyVector)[MyVector < 1.0e-10], collapse = ", "))
+  }
+
+  Hlist
 }
 
 
 
 
 
- trivial.constraints <- function(Blist, target = diag(M)) {
+ trivial.constraints <- function(Hlist, target = diag(M)) {
 
 
-  if (is.null(Blist))
+  if (is.null(Hlist))
     return(1)
 
-  if (is.matrix(Blist))
-    Blist <- list(Blist)
-  M <- dim(Blist[[1]])[1]
+  if (is.matrix(Hlist))
+    Hlist <- list(Hlist)
+  M <- dim(Hlist[[1]])[1]
 
   if (!is.matrix(target)) 
     stop("target is not a matrix")
   dimtar <- dim(target) 
 
-  trivc <- rep(1, length(Blist))
-  names(trivc) <- names(Blist)
-  for (ii in 1:length(Blist)) {
-    d <- dim(Blist[[ii]])
+  trivc <- rep(1, length(Hlist))
+  names(trivc) <- names(Hlist)
+  for (ii in 1:length(Hlist)) {
+    d <- dim(Hlist[[ii]])
     if (d[1] != dimtar[1]) trivc[ii] <- 0
     if (d[2] != dimtar[2]) trivc[ii] <- 0
     if (d[1] != M)         trivc[ii] <- 0
-    if (length(Blist[[ii]]) != length(target))
+    if (length(Hlist[[ii]]) != length(target))
       trivc[ii] <- 0
     if (trivc[ii] == 0) next
-    if (!all(c(Blist[[ii]]) == c(target)))
+    if (!all(c(Hlist[[ii]]) == c(target)))
       trivc[ii] <- 0
     if (trivc[ii] == 0) next
   }
@@ -335,7 +583,7 @@ cm.nointercept.vgam <- function(constraints, x, nointercept, M) {
   if (empty.list(constraints))
     if (is.list(new.constraints))
       return(new.constraints) else 
-      return(list()) # Both NULL probably
+      return(list())  # Both NULL probably
 
   constraints <- as.list(constraints)
   new.constraints <- as.list(new.constraints)
@@ -383,7 +631,7 @@ cm.nointercept.vgam <- function(constraints, x, nointercept, M) {
 
 
 
- iam <- function(j, k, M, # hbw = M,
+ iam <- function(j, k, M,  # hbw = M,
                  both = FALSE, diag = TRUE) {
 
 
@@ -438,13 +686,9 @@ cm.nointercept.vgam <- function(constraints, x, nointercept, M) {
 
 
 
- m2avglm <- function(object, upper = FALSE, allow.vector = FALSE)  {
-  m2adefault(wweights(object), M = object@misc$M,
-             upper = upper, allow.vector = allow.vector)
-}
+ m2a <- function(m, M, upper = FALSE, allow.vector = FALSE) {
 
 
- m2adefault <- function(m, M, upper = FALSE, allow.vector = FALSE) {
   if (!is.numeric(m))
       stop("argument 'm' is not numeric")
 
@@ -459,7 +703,7 @@ cm.nointercept.vgam <- function(constraints, x, nointercept, M) {
     stop("bad value for 'M'; it is too big") 
   }
 
-  fred <- dotC(name = "m2a", as.double(t(m)), ans=double(M*M*n),
+  fred <- .C("m2a", as.double(t(m)), ans=double(M*M*n),
       as.integer(dimm),
       as.integer(index$row-1),  
       as.integer(index$col-1),  
@@ -488,10 +732,10 @@ cm.nointercept.vgam <- function(constraints, x, nointercept, M) {
   index <- iam(NA, NA, M, both = TRUE, diag = TRUE)
 
 
-  fred <- dotC(name = "a2m", as.double(a), m=double(dimm.value*n),
+  fred <- .C("a2m",
+             as.double(a), m = double(dimm.value * n),
       as.integer(dimm.value),
-      as.integer(index$row-1),  
-      as.integer(index$col-1),  
+      as.integer(index$row-1),  as.integer(index$col-1),  
       as.integer(n),  as.integer(M), NAOK = TRUE)
   dim(fred$m) <- c(dimm.value,n)
   fred$m <- t(fred$m)
@@ -532,22 +776,15 @@ cm.nointercept.vgam <- function(constraints, x, nointercept, M) {
 
 
 
-if(!exists("is.R"))
-  is.R <- function()
-    exists("version") &&
-    !is.null(version$language) &&
-    version$language == "R"
-
-
-
-
-
  wweights <- function(object, matrix.arg = TRUE, deriv.arg = FALSE,
                       ignore.slot = FALSE, checkwz = TRUE) {
 
 
 
 
+
+
+
   if (length(wz <- object@weights) && !ignore.slot && !deriv.arg) { 
     return(wz) 
   }
@@ -564,8 +801,8 @@ if(!exists("is.R"))
   mu <- object@fitted.values
   if (any(slotNames(object) == "predictors"))
     eta <- object@predictors
-  mt <- terms(object) # object@terms$terms; 11/8/03 
-  Blist <- constraints <- object@constraints 
+  mt <- terms(object)  # object@terms$terms; 20030811
+  Hlist <- constraints <- object@constraints 
   new.coeffs <- object@coefficients
   if (any(slotNames(object) == "iter"))
     iter <- object@iter
@@ -579,17 +816,42 @@ if(!exists("is.R"))
   x <- object@x
   if (!length(x))
     x <- model.matrixvlm(object, type = "lm")
+
   y <- object@y
+  if (!length(y))
+    y <- depvar(object)
+
+
+
+  if (length(object@misc$form2)) {
+    Xm2 <- object@Xm2
+    if (!length(Xm2))
+      Xm2 <- model.matrix(object, type = "lm2")
+    Ym2 <- object@Ym2
+  }
+
+
+
+
+  if (any(slotNames(object) == "family")) {
+    infos.list <- object@family@infos()
+    if (length(infos.list))
+      for (ii in names(infos.list)) {
+        assign(ii, infos.list[[ii]])
+      }
+  }
+
+
 
   if (any(slotNames(object) == "control"))
-  for (ii in names(object@control)) {
-      assign(ii, object@control[[ii]]) 
-  } 
+    for (ii in names(object@control)) {
+      assign(ii, object@control[[ii]])
+    } 
 
   if (length(object@misc))
-  for (ii in names(object@misc)) {
-    assign(ii, object@misc[[ii]]) 
-  } 
+    for (ii in names(object@misc)) {
+      assign(ii, object@misc[[ii]]) 
+    } 
 
   if (any(slotNames(object) == "family")) {
     expr <- object@family@deriv
@@ -600,7 +862,7 @@ if(!exists("is.R"))
 
 
       if (M > 1) 
-        dimnames(wz) <- list(dimnames(wz)[[1]], NULL) # Remove colnames
+        dimnames(wz) <- list(dimnames(wz)[[1]], NULL)  # Remove colnames
       wz <- if (matrix.arg) as.matrix(wz) else c(wz) 
     }
     if (deriv.arg) list(deriv = deriv.mu, weights = wz) else wz
@@ -618,7 +880,7 @@ if(!exists("is.R"))
     ans 
   } else {
     temp <- object@y
-    ans <- rep(1, nrow(temp)) # Assumed all equal and unity.
+    ans <- rep(1, nrow(temp))  # Assumed all equal and unity.
     names(ans) <- dimnames(temp)[[1]]
     ans 
   }
@@ -633,11 +895,15 @@ procVec <- function(vec, yn, Default) {
 
 
 
+
+
+
+
   if (any(is.na(vec)))
     stop("vec cannot contain any NAs")
   L <- length(vec)
-  nvec <- names(vec)     # vec[""] undefined
-  named <- length(nvec)   # FALSE for c(1,3)
+  nvec <- names(vec)  # vec[""] undefined
+  named <- length(nvec)  # FALSE for c(1,3)
   if (named) {
     index <- (1:L)[nvec == ""]
     default <- if (length(index)) vec[index] else Default
@@ -667,12 +933,7 @@ procVec <- function(vec, yn, Default) {
 
 if (FALSE) {
 
-if (!isGeneric("m2a"))
-    setGeneric("m2a", function(object, ...) standardGeneric("m2a"))
 
-setMethod("m2a", "vglm",
-         function(object, ...)
-         m2avglm(object, ...))
 }
 
 
@@ -727,16 +988,8 @@ setMethod("weights", "vglm",
 
 
 
-dotFortran <- function(name, ..., NAOK = FALSE, DUP = TRUE,
-                       PACKAGE = "VGAM") {
-  .Fortran(name, ..., NAOK = NAOK, DUP = DUP, PACKAGE = PACKAGE)
-}
 
 
-dotC <- function(name, ..., NAOK = FALSE, DUP = TRUE,
-                 PACKAGE = "VGAM") {
-  .C(name, ..., NAOK = NAOK, DUP = DUP, PACKAGE = PACKAGE)
-}
 
 
 
@@ -750,8 +1003,9 @@ qnupdate <- function(w, wzold, dderiv, deta, M, keeppd = TRUE,
     dderiv <- cbind(dderiv)
     deta <- cbind(deta)
   }
-  Bs <- mux22(t(wzold), deta, M = M, upper = FALSE, as.matrix = TRUE) # n x M
-  sBs <- c( (deta * Bs) %*% rep(1, M) )   # should have positive values
+  Bs <- mux22(t(wzold), deta, M = M,
+              upper = FALSE, as.matrix = TRUE)  # n x M
+  sBs <- c( (deta * Bs) %*% rep(1, M) )  # should have positive values
   sy <- c( (dderiv * deta) %*% rep(1, M) )
   wznew <- wzold
   index <- iam(NA, NA, M = M, both = TRUE)
@@ -781,8 +1035,9 @@ qnupdate <- function(w, wzold, dderiv, deta, M, keeppd = TRUE,
 
 
 
+
 mbesselI0 <- function(x, deriv.arg = 0) {
-  if (!is.Numeric(deriv.arg, allowable.length = 1,
+  if (!is.Numeric(deriv.arg, length.arg = 1,
                   integer.valued = TRUE, positive = TRUE) &&
       deriv.arg != 0)
     stop("argument 'deriv.arg' must be a single non-negative integer")
@@ -829,11 +1084,11 @@ VGAM.matrix.norm <- function(A, power = 2, suppressWarning = FALSE) {
 rmfromVGAMenv <- function(varnames, prefix = "") {
   evarnames <- paste(prefix, varnames, sep = "")
   for (ii in evarnames) {
-    mytext1 <- "exists(x = ii, envir = VGAM:::VGAMenv)"
+    mytext1 <- "exists(x = ii, envir = VGAMenv)"
     myexp1 <- parse(text = mytext1)
     is.there <- eval(myexp1)
     if (is.there) {
-      rm(list = ii, envir = VGAM:::VGAMenv)
+      rm(list = ii, envir = VGAMenv)
     }
   }
 }
@@ -845,7 +1100,7 @@ existsinVGAMenv <- function(varnames, prefix = "") {
   evarnames <- paste(prefix, varnames, sep = "")
   ans <- NULL
   for (ii in evarnames) {
-    mytext1 <- "exists(x = ii, envir = VGAM:::VGAMenv)"
+    mytext1 <- "exists(x = ii, envir = VGAMenv)"
     myexp1 <- parse(text = mytext1)
     is.there <- eval(myexp1)
     ans <- c(ans, is.there)
@@ -858,7 +1113,7 @@ assign2VGAMenv <- function(varnames, mylist, prefix = "") {
   evarnames <- paste(prefix, varnames, sep = "")
   for (ii in 1:length(varnames)) {
     assign(evarnames[ii], mylist[[(varnames[ii])]],
-           envir = VGAM:::VGAMenv)
+           envir = VGAMenv)
   }
 }
 
@@ -871,7 +1126,7 @@ getfromVGAMenv <- function(varname, prefix = "") {
   varname <- paste(prefix, varname, sep = "")
   if (length(varname) > 1)
     stop("'varname' must be of length 1")
-  get(varname, envir = VGAM:::VGAMenv)
+  get(varname, envir = VGAMenv)
 }
 
  
@@ -881,10 +1136,10 @@ lerch <- function(x, s, v, tolerance = 1.0e-10, iter = 100) {
     stop("bad input in 'x', 's', and/or 'v'")
   if (is.complex(c(x,s,v)))
     stop("complex arguments not allowed in 'x', 's' and 'v'")
-  if (!is.Numeric(tolerance, allowable.length = 1, positive = TRUE) ||
+  if (!is.Numeric(tolerance, length.arg = 1, positive = TRUE) ||
       tolerance > 0.01)
     stop("bad input for argument 'tolerance'")
-  if (!is.Numeric(iter, allowable.length = 1,
+  if (!is.Numeric(iter, length.arg = 1,
                   integer.valued = TRUE, positive = TRUE))
     stop("bad input for argument 'iter'")
 
@@ -895,7 +1150,8 @@ lerch <- function(x, s, v, tolerance = 1.0e-10, iter = 100) {
   xok <- abs(x) < 1 & !(v <= 0 & v == round(v))
   x[!xok] <- 0  # Fix this later
 
-  ans <- dotC(name = "lerchphi123", err = integer(L), as.integer(L),
+  ans <- .C("lerchphi123",
+           err = integer(L), as.integer(L),
            as.double(x), as.double(s), as.double(v),
            acc=as.double(tolerance), result=double(L),
            as.integer(iter))
@@ -906,7 +1162,7 @@ lerch <- function(x, s, v, tolerance = 1.0e-10, iter = 100) {
 
 
 
-negzero.expression <- expression({
+negzero.expression.VGAM <- expression({
 
 
 
@@ -918,25 +1174,25 @@ negzero.expression <- expression({
   negdotzero <-  dotzero[dotzero < 0]
 
   bigUniqInt <- 1080
-  zneg_index <- if (length(negdotzero)) {
+  zneg.index <- if (length(negdotzero)) {
 
     if (!is.Numeric(-negdotzero, positive = TRUE,
                     integer.valued = TRUE) ||
-        max(-negdotzero) > Musual)
+        max(-negdotzero) > M1)
         stop("bad input for argument 'zero'")
 
-    zneg_index <- rep(0:bigUniqInt, rep(length(negdotzero),
-                      1 + bigUniqInt)) * Musual + abs(negdotzero)
-    sort(intersect(zneg_index, 1:M))
+    zneg.index <- rep(0:bigUniqInt, rep(length(negdotzero),
+                      1 + bigUniqInt)) * M1 + abs(negdotzero)
+    sort(intersect(zneg.index, 1:M))
   } else {
     NULL
   }
 
-  zpos_index <- if (length(posdotzero)) posdotzero else NULL
-  z_Index <- if (!length(dotzero)) NULL else
-                   unique(sort(c(zneg_index, zpos_index)))
+  zpos.index <- if (length(posdotzero)) posdotzero else NULL
+  z.Index <- if (!length(dotzero)) NULL else
+                   unique(sort(c(zneg.index, zpos.index)))
 
-  constraints <- cm.zero.vgam(constraints, x, z_Index, M)
+  constraints <- cm.zero.VGAM(constraints, x = x, z.Index, M = M)
 })
 
 
@@ -961,6 +1217,30 @@ interleave.VGAM <- function(L, M)
 
 
 
+interleave.cmat <- function(cmat1, cmat2) {
+  ncol1 <- ncol(cmat1)
+  ncol2 <- ncol(cmat2)
+  if (ncol1 == 1) {
+    return(cbind(cmat1, cmat2))
+  } else {  # ncol1 > 1
+    if (ncol2 == 1) {
+      return(cbind(cmat1[, 1], cmat2, cmat1[, -1]))
+    } else
+    if (ncol1 != ncol2) {
+      warning("this function is confused. Returning cbind(cmat1, cmat2)")
+      return(cbind(cmat1[, 1], cmat2, cmat1[, -1]))
+    } else {  # ncol1 == ncol2 and both are > 1.
+      kronecker(cmat1, cbind(1, 0)) +
+      kronecker(cmat2, cbind(0, 1))        
+    }
+  }
+}
+
+
+
+
+
+
 w.wz.merge <- function(w, wz, n, M, ndepy,
                        intercept.only = FALSE) {
 
@@ -982,7 +1262,7 @@ w.wz.merge <- function(w, wz, n, M, ndepy,
 
   w  <- matrix(w, n, ndepy)
   w.rep <- matrix(0, n, ncol(wz))
-  Musual <- M / ndepy
+  M1 <- M / ndepy
   all.indices <- iam(NA, NA, M = M, both = TRUE)
 
 
@@ -990,17 +1270,17 @@ w.wz.merge <- function(w, wz, n, M, ndepy,
   if (FALSE)
   for (ii in 1:ncol(wz)) {
 
-    if ((ind1 <- ceiling(all.indices$row[ii] / Musual)) ==
-                 ceiling(all.indices$col[ii] / Musual)) {
+    if ((ind1 <- ceiling(all.indices$row[ii] / M1)) ==
+                 ceiling(all.indices$col[ii] / M1)) {
       w.rep[, ii] <- w[, ind1]
     }
 
 
-  } # ii
+  }  # ii
 
 
-  res.Ind1 <- ceiling(all.indices$row.index / Musual)
-  Ind1 <- res.Ind1 == ceiling(all.indices$col.index / Musual)
+  res.Ind1 <- ceiling(all.indices$row.index / M1)
+  Ind1 <- res.Ind1 == ceiling(all.indices$col.index / M1)
 
   LLLL <- min(ncol(wz), length(Ind1))
   Ind1 <- Ind1[1:LLLL]
@@ -1009,7 +1289,7 @@ w.wz.merge <- function(w, wz, n, M, ndepy,
   for (ii in 1:ndepy) {
     sub.ind1 <- (1:LLLL)[Ind1 & (res.Ind1 == ii)]
     w.rep[, sub.ind1] <- w[, ii]
-  } # ii
+  }  # ii
 
   w.rep * wz
 }
@@ -1037,7 +1317,7 @@ w.y.check <- function(w, y,
     w <- as.matrix(w)
   if (!is.matrix(y))
     y <- as.matrix(y)
-  n_lm <- nrow(y)
+  n.lm <- nrow(y)
   rn.w <- rownames(w)
   rn.y <- rownames(y)
   cn.w <- colnames(w)
@@ -1051,7 +1331,7 @@ w.y.check <- function(w, y,
   if (Is.nonnegative.y && any(y < 0))
     stop("response variable 'y' must be 0 or positive-valued")
 
-  if (nrow(w) != n_lm)
+  if (nrow(w) != n.lm)
     stop("nrow(w) should be equal to nrow(y)")
 
   if (ncol(w) > ncol.w.max)
@@ -1089,7 +1369,7 @@ w.y.check <- function(w, y,
     if (length(cn.w) < Ncol.max.w)
       cn.w <- c(cn.w, paste(prefix.w, (length(cn.w)+1):Ncol.max.w,
                             sep = ""))
-    w <- matrix(w, n_lm, Ncol.max.w, dimnames = list(rn.w, cn.w))
+    w <- matrix(w, n.lm, Ncol.max.w, dimnames = list(rn.w, cn.w))
   }
   if (out.wy && ncol(y) < Ncol.max.y) {
     nblanks <- sum(cn.y == "")
@@ -1098,7 +1378,7 @@ w.y.check <- function(w, y,
     if (length(cn.y) < Ncol.max.y)
       cn.y <- c(cn.y, paste(prefix.y, (length(cn.y)+1):Ncol.max.y,
                             sep = ""))
-    y <- matrix(y, n_lm, Ncol.max.y, dimnames = list(rn.y, cn.y))
+    y <- matrix(y, n.lm, Ncol.max.y, dimnames = list(rn.y, cn.y))
   }
        
   list(w = if (out.wy) w else NULL,
@@ -1109,7 +1389,7 @@ w.y.check <- function(w, y,
 
 
 
-arwz2wz <- function(arwz, M = 1, Musual = 1) {
+arwz2wz <- function(arwz, M = 1, M1 = 1) {
 
 
 
@@ -1124,14 +1404,14 @@ arwz2wz <- function(arwz, M = 1, Musual = 1) {
     return(arwz)
   }
 
-  wz <- matrix(0.0, nrow = n, ncol = sum(M:(M-Musual+1)))
-  ind1 <- iam(NA, NA, M = Musual, both = TRUE, diag = TRUE)
+  wz <- matrix(0.0, nrow = n, ncol = sum(M:(M-M1+1)))
+  ind1 <- iam(NA, NA, M = M1, both = TRUE, diag = TRUE)
   len.ind1 <- dim.val # length(ind1$col.index)
 
   for (ii in 1:ndepy) {
     for (jlocal in 1:len.ind1) {
-      wz[, iam(Musual * (ii - 1) + ind1$row[jlocal],
-               Musual * (ii - 1) + ind1$col[jlocal],
+      wz[, iam(M1 * (ii - 1) + ind1$row[jlocal],
+               M1 * (ii - 1) + ind1$col[jlocal],
                M = M)] <- arwz[, ii, jlocal]
     }
   }
@@ -1152,6 +1432,15 @@ arwz2wz <- function(arwz, M = 1, Musual = 1) {
 
 
 
+
+param.names <- function(string, S) {
+  if (S == 1) string else paste(string, 1:S, sep = "")
+}
+
+
+
+
+
 vweighted.mean.default <- function (x, w, ..., na.rm = FALSE) {
   temp5 <- w.y.check(w = w, y = x, ncol.w.max = Inf, ncol.y.max = Inf,
                      out.wy = TRUE,
@@ -1175,3 +1464,41 @@ vweighted.mean.default <- function (x, w, ..., na.rm = FALSE) {
 
 
 
+
+
+familyname.vlm <- function(object, all = FALSE, ...) {
+  ans <- object@family@vfamily
+  if (all) ans else ans[1]
+}
+
+
+familyname.vglmff <- function(object, all = FALSE, ...) {
+  ans <- object@vfamily
+  if (all) ans else ans[1]
+}
+
+
+
+if (!isGeneric("familyname"))
+    setGeneric("familyname",
+  function(object, ...) standardGeneric("familyname"))
+
+
+setMethod("familyname", "vglmff",
+         function(object, ...)
+         familyname.vglmff(object, ...))
+
+
+
+setMethod("familyname", "vlm",
+         function(object, ...)
+         familyname.vlm(object, ...))
+
+
+
+
+
+
+
+
+
