@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2013 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2015 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -17,13 +17,14 @@ dcard <- function(x, mu, rho, log = FALSE) {
 
 
   L <- max(length(x), length(mu), length(rho))
-  x   <- rep(x,   len = L);
-  mu  <- rep(mu,  len = L);
-  rho <- rep(rho, len = L);
+  if (length(x)   != L) x   <- rep(x,   len = L)
+  if (length(mu)  != L) mu  <- rep(mu,  len = L)
+  if (length(rho) != L) rho <- rep(rho, len = L)
+
   logdensity <- rep(log(0), len = L)
   xok <- (x > 0) & (x < (2*pi))
   logdensity[xok] <- -log(2*pi) + log1p(2 * rho[xok] *
-                     cos(x[xok]-mu[xok]))
+                      cos(x[xok]-mu[xok]))
   logdensity[mu  <=    0] <- NaN
   logdensity[mu  >= 2*pi] <- NaN
   logdensity[rho <= -0.5] <- NaN
@@ -32,76 +33,154 @@ dcard <- function(x, mu, rho, log = FALSE) {
 }
 
 
-pcard <- function(q, mu, rho) {
-  if (!is.Numeric(mu) || any(mu < 0) || any(mu > 2*pi))
-    stop("'mu' must be between 0 and 2*pi inclusive")
-  if (!is.Numeric(rho) || max(abs(rho) > 0.5))
-    stop("'rho' must be between -0.5 and 0.5 inclusive")
-  ans <- (q + 2 * rho * (sin(q-mu) + sin(mu))) / (2*pi)
-  ans[q >= (2*pi)] <- 1
-  ans[q <= 0] <- 0
+
+pcard <- function(q, mu, rho, lower.tail = TRUE, log.p = FALSE) {
+  
+  if (!is.logical(lower.tail) || length(lower.tail ) != 1)
+    stop("bad input for argument 'lower.tail'")
+  if (!is.logical(log.p) || length(log.p) != 1)
+    stop("bad input for argument 'log.p'")
+
+  if (lower.tail) {
+    if (log.p) {
+      ans <- log((q + 2 * rho * (sin(q-mu) + sin(mu))) / (2*pi))
+      ans[q <= 0 ] <- -Inf
+      ans[q >= (2*pi)]  <- 0
+    } else {
+      ans <- (q + 2 * rho * (sin(q-mu) + sin(mu))) / (2*pi)
+      ans[q <= 0] <- 0
+      ans[q >= (2*pi)] <- 1
+    }
+  } else {
+    if (log.p) {
+      ans <- log1p(-(q + 2 * rho * (sin(q-mu) + sin(mu))) / (2*pi))
+      ans[q <= 0] <- 0
+      ans[q >= (2*pi)]  <- -Inf
+    } else {
+      ans <- (2*pi - q - 2 * rho * (sin(q-mu) + sin(mu))) / (2*pi)
+      ans[q <= 0] <- 1
+      ans[q >= (2*pi)] <- 0
+    }
+  } 
+  ans[mu < 0 | mu > 2*pi] <- NaN  # A warning() may be a good idea here
+  ans[abs(rho) > 0.5] <- NaN
   ans
 }
 
 
 
-qcard <- function(p, mu, rho, tolerance=1.0e-7, maxits=500) {
-  if (!is.Numeric(mu) || any(mu < 0) || any(mu > 2*pi))
-    stop("'mu' must be between 0 and 2*pi inclusive")
-  if (!is.Numeric(rho) || max(abs(rho) > 0.5))
-    stop("'rho' must be between -0.5 and 0.5 inclusive")
-  if (!is.Numeric(p, positive = TRUE) || any(p > 1))
+qcard <- function(p, mu, rho, tolerance = 1.0e-7, maxits = 500,
+                  lower.tail = TRUE, log.p = FALSE) {
+  if (!is.Numeric(p) || any(p < 0) || any(p > 1))
     stop("'p' must be between 0 and 1")
+
   nn <- max(length(p), length(mu), length(rho))
-  p <- rep(p, len=nn)
-  mu <- rep(mu, len=nn)
-  rho <- rep(rho, len=nn)
+  if (length(p)   != nn) p   <- rep(p,   len = nn)
+  if (length(mu)  != nn) mu  <- rep(mu,  len = nn)
+  if (length(rho) != nn) rho <- rep(rho, len = nn)
 
 
-  oldans <- 2 * pi * p
-
-  for(its in 1:maxits) {
-    ans <- oldans - (oldans + 2 * rho * (sin(oldans-mu)+sin(mu)) -
-           2*pi*p) / (1 + 2 * rho * cos(oldans - mu))
-    index <- (ans <= 0) | (ans > 2*pi)
-    if (any(index)) {
-      ans[index] <- runif (sum(index), 0, 2*pi)
+  if (!is.logical(lower.tail) || length(lower.tail ) != 1)
+    stop("bad input for argument 'lower.tail'")
+  if (!is.logical(log.p) || length(log.p) != 1)
+    stop("bad input for argument 'log.p'")
+  
+  if (lower.tail) {
+    if (log.p) {
+      ln.p <- p
+      for (its in 1:maxits) {
+        oldans <- 2 * pi * exp(ln.p)
+        ans <- oldans - (oldans + 2 * rho * (sin(oldans-mu)+sin(mu)) -
+                           2*pi*exp(ln.p)) / (1 + 2 * rho * cos(oldans - mu))
+        index <- (ans < 0) | (ans > 2*pi)  # 20141216 KaiH  Remove ans == 0
+        if (any(index)) {
+          ans[index] <- runif (sum(index), 0, 2*pi)
+        }
+        if (max(abs(ans - oldans)) < tolerance) break;
+        if (its == maxits) {warning("did not converge"); break}
+        oldans <- ans
       }
-    if (max(abs(ans - oldans)) < tolerance) break;
-    if (its == maxits) {warning("did not converge"); break}
-    oldans <- ans
+    } else {
+      for (its in 1:maxits) {
+        oldans <- 2 * pi * p
+        ans <- oldans - (oldans + 2 * rho * (sin(oldans-mu)+sin(mu)) -
+               2*pi*p) / (1 + 2 * rho * cos(oldans - mu))
+        index <- (ans < 0) | (ans > 2*pi)  # 20141216 KaiH  Remove ans == 0
+        if (any(index)) {
+          ans[index] <- runif(sum(index), 0, 2*pi)
+        }
+        if (max(abs(ans - oldans)) < tolerance) break;
+        if (its == maxits) {warning("did not converge"); break}
+        oldans <- ans
+      }
+    }
+  } else {
+    if (log.p) {
+      ln.p <- p
+      for (its in 1:maxits) {
+        oldans <- - 2 * pi * expm1(ln.p)
+        ans <- oldans - (oldans + 2 * rho * (sin(oldans-mu)+sin(mu)) +
+               2*pi*expm1(ln.p)) / (1 + 2 * rho * cos(oldans - mu))
+        index <- (ans < 0) | (ans > 2*pi)
+        if (any(index)) {
+          ans[index] <- runif (sum(index), 0, 2*pi)
+        }
+        if (max(abs(ans - oldans)) < tolerance) break;
+        if (its == maxits) {warning("did not converge"); break}
+        oldans <- ans 
+       }
+    } else { 
+      for (its in 1:maxits) {
+        oldans <- 2 * pi - 2 * pi * p
+        ans <- oldans - (oldans + 2 * rho * (sin(oldans-mu)+sin(mu)) -
+               2*pi + 2*pi*p) / (1 + 2 * rho * cos(oldans - mu))
+        index <- (ans < 0) | (ans > 2*pi)  
+        if (any(index)) {
+          ans[index] <- runif (sum(index), 0, 2*pi)
+        }
+        if (max(abs(ans - oldans)) < tolerance) break;
+        if (its == maxits) {warning("did not converge"); break}
+        oldans <- ans
+      }
+    }
   }
+
+  ans[mu < 0 | mu > 2*pi] <- NaN  # A warning() may be a good idea here
+  ans[abs(rho) > 0.5] <- NaN
   ans
 }
 
 
 
 rcard <- function(n, mu, rho, ...) {
+  use.n <- if ((length.n <- length(n)) > 1) length.n else
+           if (!is.Numeric(n, integer.valued = TRUE,
+                           length.arg = 1, positive = TRUE))
+              stop("bad input for argument 'n'") else n
+
+
   if (!is.Numeric(mu) || any(mu < 0) || any(mu > 2*pi))
     stop("argument 'mu' must be between 0 and 2*pi inclusive")
   if (!is.Numeric(rho) || max(abs(rho) > 0.5))
     stop("argument 'rho' must be between -0.5 and 0.5 inclusive")
-  if (!is.Numeric(n, positive = TRUE,
-                  integer.valued = TRUE, allowable.length = 1))
-    stop("argument 'n' must be a single positive integer")
 
-  mu <- rep(mu, len = n)
-  rho <- rep(rho, len = n)
-  qcard(runif (n), mu = mu, rho = rho, ...)
+  mu <- rep(mu, len = use.n)
+  rho <- rep(rho, len = use.n)
+  qcard(runif(use.n), mu = mu, rho = rho, ...)
 }
 
 
 
 
-cardioid.control <- function(save.weight = TRUE, ...) {
-    list(save.weight = save.weight)
+cardioid.control <- function(save.weights = TRUE, ...) {
+    list(save.weights = save.weights)
 }
 
 
 
  cardioid <- function(
-     lmu  = elogit(min = 0, max = 2*pi),
-     lrho = elogit(min = -0.5, max = 0.5),
+     lmu  = extlogit(min = 0, max = 2*pi),
+     lrho = extlogit(min = -0.5, max = 0.5),
      imu = NULL, irho = 0.3,
      nsimEIM = 100, zero = NULL) {
 
@@ -121,7 +200,7 @@ cardioid.control <- function(save.weight = TRUE, ...) {
   if (!is.Numeric(irho) || max(abs(irho)) > 0.5)
     stop("bad input for argument 'irho'")
 
-  if (!is.Numeric(nsimEIM, allowable.length = 1,
+  if (!is.Numeric(nsimEIM, length.arg = 1,
                   integer.valued = TRUE) ||
       nsimEIM <= 50)
     stop("'nsimEIM' should be an integer greater than 50")
@@ -136,7 +215,7 @@ cardioid.control <- function(save.weight = TRUE, ...) {
             "pi + (rho/pi) *",
             "((2*pi-mu)*sin(2*pi-mu)+cos(2*pi-mu)-mu*sin(mu)-cos(mu))"),
   constraints = eval(substitute(expression({
-    constraints <- cm.zero.vgam(constraints, x, .zero, M)
+    constraints <- cm.zero.VGAM(constraints, x = x, .zero , M = M)
   }), list( .zero = zero ))),
   initialize = eval(substitute(expression({
 
@@ -167,9 +246,9 @@ cardioid.control <- function(save.weight = TRUE, ...) {
       }
       mu.grid <- seq(0.1, 6.0, len=19)
       mu.init <- if (length( .imu )) .imu else
-          getMaxMin(mu.grid, objfun = cardioid.Loglikfun,
-                    y = y,  x = x, w = w,
-                    extraargs = list(irho = rho.init))
+          grid.search(mu.grid, objfun = cardioid.Loglikfun,
+                      y = y,  x = x, w = w,
+                      extraargs = list(irho = rho.init))
       mu.init <- rep(mu.init, length=length(y))
       etastart <-
         cbind(theta2eta( mu.init, .lmu,  earg = .emu),
@@ -195,16 +274,39 @@ cardioid.control <- function(save.weight = TRUE, ...) {
   }), list( .lmu = lmu, .lrho = lrho,
             .emu = emu, .erho = erho, .nsimEIM = nsimEIM ))),
   loglikelihood = eval(substitute(
-    function(mu, y, w, residuals = FALSE, eta, extra = NULL) {
+    function(mu, y, w, residuals = FALSE, eta, extra = NULL,
+             summation = TRUE) {
     mu  <- eta2theta(eta[, 1], link = .lmu, earg = .emu)
     rho <- eta2theta(eta[, 2], link = .lrho, earg = .erho)
-    if (residuals) stop("loglikelihood residuals not ",
-                        "implemented yet") else {
-      sum(w * dcard(x = y, mu = mu, rho = rho, log = TRUE))
+    if (residuals) {
+      stop("loglikelihood residuals not implemented yet")
+    } else {
+      ll.elts <- c(w) * dcard(x = y, mu = mu, rho = rho, log = TRUE)
+      if (summation) {
+        sum(ll.elts)
+      } else {
+        ll.elts
+      }
     }
-  }, list( .lmu = lmu, .lrho=lrho,
-           .emu = emu, .erho=erho ))),
+  }, list( .lmu = lmu, .lrho = lrho,
+           .emu = emu, .erho = erho ))),
   vfamily = c("cardioid"),
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
   deriv = eval(substitute(expression({
     mu  <- eta2theta(eta[, 1], link = .lmu,  earg = .emu)
     rho <- eta2theta(eta[, 2], link = .lrho, earg = .erho)
@@ -222,7 +324,7 @@ cardioid.control <- function(save.weight = TRUE, ...) {
     run.varcov <- 0
     ind1   <- iam(NA, NA, M = M, both = TRUE, diag = TRUE)
     index0 <- iam(NA, NA, M = M, both = TRUE, diag = TRUE)
-    for(ii in 1:( .nsimEIM )) {
+    for (ii in 1:( .nsimEIM )) {
       ysim <- rcard(n, mu=mu, rho=rho)
       dl.dmu <-  2 * rho * sin(ysim-mu) / (1 + 2 * rho * cos(ysim-mu))
       dl.drho <- 2 * cos(ysim-mu) / (1 + 2 * rho * cos(ysim-mu))
@@ -244,7 +346,7 @@ cardioid.control <- function(save.weight = TRUE, ...) {
 
 
 
- vonmises <- function(llocation = elogit(min = 0, max = 2*pi),
+ vonmises <- function(llocation = extlogit(min = 0, max = 2*pi),
                       lscale  = "loge",
                       ilocation = NULL, iscale  = NULL,
                       imethod = 1, zero = NULL) {
@@ -260,7 +362,7 @@ cardioid.control <- function(save.weight = TRUE, ...) {
   ilocat <- ilocation
 
 
-  if (!is.Numeric(imethod, allowable.length = 1,
+  if (!is.Numeric(imethod, length.arg = 1,
                   integer.valued = TRUE, positive = TRUE) ||
      imethod > 2)
     stop("argument 'imethod' must be 1 or 2")
@@ -279,10 +381,10 @@ cardioid.control <- function(save.weight = TRUE, ...) {
             "\n", "\n",
             "Mean:     location"),
   constraints = eval(substitute(expression({
-    constraints <- cm.zero.vgam(constraints, x, .zero, M)
+    constraints <- cm.zero.VGAM(constraints, x = x, .zero , M = M)
   }), list( .zero = zero ))),
   infos = eval(substitute(function(...) {
-    list(Musual = 2,
+    list(M1 = 2,
          zero = .zero ,
          parameterNames = c("location", "scale"))
   }, list( .zero = zero ))),
@@ -315,7 +417,7 @@ cardioid.control <- function(save.weight = TRUE, ...) {
             theta2eta(locat.init, .llocat, earg = .elocat),
             theta2eta(scale.init, .lscale, earg = .escale))
       }
-      y <- y %% (2*pi) # Coerce after initial values have been computed
+      y <- y %% (2*pi)  # Coerce after initial values have been computed
   }), list( .imethod = imethod, .ilocat = ilocat,
             .escale = escale, .elocat = elocat,
             .lscale = lscale, .llocat = llocat,
@@ -333,14 +435,21 @@ cardioid.control <- function(save.weight = TRUE, ...) {
   }), list( .llocat = llocat, .lscale = lscale,
             .elocat = elocat, .escale = escale ))),
   loglikelihood = eval(substitute(
-    function(mu,y,w,residuals= FALSE,eta, extra = NULL) {
+    function(mu, y, w, residuals = FALSE, eta, extra = NULL,
+             summation = TRUE) {
     locat <- eta2theta(eta[, 1], .llocat, earg = .elocat)
     Scale <- eta2theta(eta[, 2], .lscale, earg = .escale)
 
-    if (residuals) stop("loglikelihood residuals not ",
-                          "implemented yet") else
-      sum(w * (Scale * cos(y - locat) -
-               log(mbesselI0(x = Scale ))))
+    if (residuals) {
+      stop("loglikelihood residuals not implemented yet")
+    } else {
+      ll.elts <- c(w) * (Scale * cos(y - locat) - log(mbesselI0(x = Scale)))
+      if (summation) {
+        sum(ll.elts)
+      } else {
+        ll.elts
+      }
+    }
   }, list( .escale = escale, .lscale = lscale,
            .llocat = llocat, .elocat = elocat ))),
   vfamily = c("vonmises"),
@@ -364,7 +473,7 @@ cardioid.control <- function(save.weight = TRUE, ...) {
     ned2l.dlocat2 <- Scale * tmp6[, 2] / tmp6[, 1]
     ned2l.dscale2 <- tmp6[, 3] / tmp6[, 1] - (tmp6[, 2] / tmp6[, 1])^2
 
-    wz <- matrix(as.numeric(NA), nrow = n, ncol = 2) # diagonal
+    wz <- matrix(as.numeric(NA), nrow = n, ncol = 2)  # diagonal
     wz[,iam(1, 1, M)] <- ned2l.dlocat2 * dlocat.deta^2
     wz[,iam(2, 2, M)] <- ned2l.dscale2 * dscale.deta^2
     c(w) * wz
