@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2013 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2015 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -68,10 +68,14 @@ get.arg <- function(string) {
 
 
 
+
+
  eifun <- function(i, n)
     cbind(as.numeric((1:n) == i))
 
- eifun <- function(i, n)
+
+ eifun <-
+ I.col <- function(i, n)
     diag(n)[, i, drop = FALSE]
 
  eijfun <- function(i, n) {
@@ -89,9 +93,8 @@ dneg.binomial <- function(x, k, prob) {
 }
 
 
-tapplymat1 <-
-  function(mat,
-           function.arg = c("cumsum", "diff", "cumprod")) {
+
+tapplymat1 <- function(mat, function.arg = c("cumsum", "diff", "cumprod")) {
 
 
   if (!missing(function.arg))
@@ -99,25 +102,21 @@ tapplymat1 <-
   function.arg <- match.arg(function.arg,
                             c("cumsum", "diff", "cumprod"))[1]
 
-  type <- switch(function.arg,
-      cumsum = 1,
-      diff = 2,
-      cumprod = 3,
-      stop("function.arg not matched"))
+  type <- switch(function.arg, cumsum = 1, diff = 2, cumprod = 3,
+           stop("argument 'function.arg' not matched"))
 
   if (!is.matrix(mat))
     mat <- as.matrix(mat)
-  nr <- nrow(mat)
-  nc <- ncol(mat)
-  fred <- dotC(name = "tapplymat1", mat = as.double(mat),
-      as.integer(nr), as.integer(nc), as.integer(type))
-
-  dim(fred$mat) <- c(nr, nc)
+  NR <- nrow(mat)
+  NC <- ncol(mat)
+  fred <- .C("tapply_mat1", mat = as.double(mat), as.integer(NR),
+             as.integer(NC), as.integer(type))  # , PACKAGE = "VGAM"
+  dim(fred$mat) <- c(NR, NC)
   dimnames(fred$mat) <- dimnames(mat)
   switch(function.arg,
-      cumsum = fred$mat,
-      diff = fred$mat[, -1, drop = FALSE],
-      cumprod = fred$mat)
+         cumsum  = fred$mat,
+         diff    = fred$mat[, -1, drop = FALSE],
+         cumprod = fred$mat)
 }
 
 
@@ -140,7 +139,7 @@ matrix.power <- function(wz, M, power, fast = TRUE) {
   }
 
   if (fast) {
-    k <- veigen(t(wz), M = M) # matrix.arg)
+    k <- veigen(t(wz), M = M)  # matrix.arg)
     evals <- k$values           # M x n
     evects <- k$vectors         # M x M x n
   } else {
@@ -198,7 +197,7 @@ wweighted.mean <- function(y, w = NULL, matrix.arg = TRUE) {
       denom <- t(w) %*% rep(1, n)
       denom <- matrix(denom, 1, length(denom))
       if (matrix.arg)
-        denom <- m2adefault(denom, M = M)[,,1]
+        denom <- m2a(denom, M = M)[, , 1]
       c(solve(denom, numer))
     }
   }
@@ -212,9 +211,9 @@ veigen <- function(x, M) {
 
   n <- ncol(x)
   index <- iam(NA, NA, M = M, both = TRUE, diag = TRUE)
-  dimm.value <- nrow(x) # usually M or M(M+1)/2
+  dimm.value <- nrow(x)  # usually M or M(M+1)/2
 
-  z <- dotFortran(name = "veigen",
+  z <- .Fortran("veigen",
       as.integer(M),
       as.integer(n),
       as.double(x),
