@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2013 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2015 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -13,20 +13,20 @@
 
 
 
-mix2normal1.control <- function(trace = TRUE, ...) {
-    list(trace = trace)
+mix2normal.control <- function(trace = TRUE, ...) {
+  list(trace = trace)
 }
 
 
- mix2normal1 <-
+ mix2normal <-
     function(lphi = "logit",
-             lmu = "identity",
+             lmu = "identitylink",
              lsd = "loge",
              iphi = 0.5,
              imu1 = NULL, imu2 = NULL,
              isd1 = NULL, isd2 = NULL,
              qmu = c(0.2, 0.8),
-             equalsd = TRUE,
+             eq.sd = TRUE,
              nsimEIM = 100,
              zero = 1) {
   lphi <- as.list(substitute(lphi))
@@ -46,14 +46,14 @@ mix2normal1.control <- function(trace = TRUE, ...) {
   esd1 <- esd2 <- esd
 
 
-  if (!is.Numeric(qmu, allowable.length = 2,
+  if (!is.Numeric(qmu, length.arg = 2,
                   positive = TRUE) ||
       any(qmu >= 1))
     stop("bad input for argument 'qmu'")
 
 
   if (length(iphi) &&
-     (!is.Numeric(iphi, allowable.length = 1,
+     (!is.Numeric(iphi, length.arg = 1,
                   positive = TRUE) ||
       iphi>= 1))
       stop("bad input for argument 'iphi'")
@@ -67,9 +67,9 @@ mix2normal1.control <- function(trace = TRUE, ...) {
     stop("bad input for argument 'isd2'")
 
 
-  if (!is.logical(equalsd) || length(equalsd) != 1)
-    stop("bad input for argument 'equalsd'")
-  if (!is.Numeric(nsimEIM, allowable.length = 1,
+  if (!is.logical(eq.sd) || length(eq.sd) != 1)
+    stop("bad input for argument 'eq.sd'")
+  if (!is.Numeric(nsimEIM, length.arg = 1,
                   integer.valued = TRUE) ||
       nsimEIM <= 10)
     stop("'nsimEIM' should be an integer greater than 10")
@@ -87,10 +87,12 @@ mix2normal1.control <- function(trace = TRUE, ...) {
             "Variance: phi*sd1^2 + (1 - phi)*sd2^2 + ",
                       "phi*(1 - phi)*(mu1-mu2)^2"),
   constraints = eval(substitute(expression({
-    constraints <- cm.vgam(rbind(diag(4), c(0, 0, 1,0)), x, .equalsd ,
-                           constraints, apply.int = TRUE)
-    constraints <- cm.zero.vgam(constraints, x, .zero , M)
-  }), list( .zero = zero, .equalsd = equalsd ))),
+    constraints <- cm.VGAM(rbind(diag(4), c(0, 0, 1, 0)), x = x,
+                           bool = .eq.sd ,
+                           constraints = constraints,
+                           apply.int = TRUE)
+    constraints <- cm.zero.VGAM(constraints, x = x, .zero , M = M)
+  }), list( .zero = zero, .eq.sd = eq.sd ))),
   initialize = eval(substitute(expression({
 
     temp5 <-
@@ -114,10 +116,10 @@ mix2normal1.control <- function(trace = TRUE, ...) {
 
 
     if (!length(etastart)) {
-      qy <- quantile(y, prob = .qmu)
-      init.phi <- rep(if(length(.iphi)) .iphi else   0.5, length = n)
-      init.mu1 <- rep(if(length(.imu1)) .imu1 else qy[1], length = n)
-      init.mu2 <- rep(if(length(.imu2)) .imu2 else qy[2], length = n)
+      qy <- quantile(y, prob = .qmu )
+      init.phi <- rep(if (length(.iphi)) .iphi else   0.5, length = n)
+      init.mu1 <- rep(if (length(.imu1)) .imu1 else qy[1], length = n)
+      init.mu2 <- rep(if (length(.imu2)) .imu2 else qy[2], length = n)
       ind.1 <- if (init.mu1[1] < init.mu2[1])
                 1:round(n* init.phi[1]) else
                 round(n* init.phi[1]):n
@@ -125,14 +127,15 @@ mix2normal1.control <- function(trace = TRUE, ...) {
                 round(n* init.phi[1]):n else
                 1:round(n* init.phi[1])
       sorty <- sort(y)
-      init.sd1 <- rep(if(length( .isd1 )) .isd1 else sd(sorty[ind.1]),
+      init.sd1 <- rep(if (length( .isd1 )) .isd1 else sd(sorty[ind.1]),
                       len = n)
-      init.sd2 <- rep(if(length( .isd2 )) .isd2 else sd(sorty[ind.2]),
+      init.sd2 <- rep(if (length( .isd2 )) .isd2 else sd(sorty[ind.2]),
                       len = n)
-      if ( .equalsd ) {
-        init.sd1 <- init.sd2 = (init.sd1 + init.sd2)/2
+      if ( .eq.sd ) {
+        init.sd1 <-
+        init.sd2 <- (init.sd1 + init.sd2) / 2
         if (!all.equal( .esd1, .esd2 ))
-          stop("'esd1' and 'esd2' must be equal if 'equalsd = TRUE'")
+          stop("'esd1' and 'esd2' must be equal if 'eq.sd = TRUE'")
       }
       etastart <- cbind(
                   theta2eta(init.phi, .lphi, earg = .ephi),
@@ -144,7 +147,7 @@ mix2normal1.control <- function(trace = TRUE, ...) {
   }), list(.lphi = lphi, .lmu = lmu,
            .iphi = iphi, .imu1 = imu1, .imu2 = imu2,
            .ephi = ephi, .emu1 = emu1, .emu2 = emu2,
-           .esd1 = esd1, .esd2 = esd2, .equalsd = equalsd,
+           .esd1 = esd1, .esd2 = esd2, .eq.sd = eq.sd,
            .lsd = lsd, .isd1 = isd1, .isd2 = isd2, .qmu = qmu))),
   linkinv = eval(substitute(function(eta, extra = NULL){
       phi <- eta2theta(eta[, 1], link = .lphi, earg = .ephi)
@@ -162,15 +165,17 @@ mix2normal1.control <- function(trace = TRUE, ...) {
                       "sd1" = .esd1, "mu2" = .emu2, "sd2" = .esd2)
 
     misc$expected <- TRUE
-    misc$equalsd <- .equalsd
+    misc$eq.sd <- .eq.sd
     misc$nsimEIM <- .nsimEIM
     misc$multipleResponses <- FALSE
-  }), list(.lphi = lphi, .lmu = lmu, .lsd = lsd, .equalsd = equalsd,
+  }), list(.lphi = lphi, .lmu = lmu, .lsd = lsd, .eq.sd = eq.sd,
            .ephi = ephi, .emu1 = emu1, .emu2 = emu2,
            .esd1 = esd1, .esd2 = esd2,
            .nsimEIM = nsimEIM ))),
   loglikelihood = eval(substitute(
-    function(mu,y,w,residuals = FALSE,eta,extra = NULL) {
+    function(mu, y, w, residuals = FALSE, eta,
+             extra = NULL,
+             summation = TRUE) {
     phi <- eta2theta(eta[, 1], link = .lphi, earg = .ephi)
     mu1 <- eta2theta(eta[, 2], link = .lmu,  earg = .emu1)
     sd1 <- eta2theta(eta[, 3], link = .lsd,  earg = .esd1)
@@ -178,14 +183,21 @@ mix2normal1.control <- function(trace = TRUE, ...) {
     sd2 <- eta2theta(eta[, 5], link = .lsd,  earg = .esd2)
     f1 <- dnorm(y, mean=mu1, sd=sd1)
     f2 <- dnorm(y, mean=mu2, sd=sd2)
-    if (residuals) stop("loglikelihood residuals not ",
-                        "implemented yet") else
-    sum(w * log(phi*f1 + (1 - phi)*f2))
+    if (residuals) {
+      stop("loglikelihood residuals not implemented yet")
+    } else {
+      ll.elts <- c(w) * log(phi*f1 + (1 - phi)*f2)
+      if (summation) {
+        sum(ll.elts)
+      } else {
+        ll.elts
+      }
+    }
   }, list(.lphi = lphi, .lmu = lmu,
           .ephi = ephi, .emu1 = emu1, .emu2 = emu2,
           .esd1 = esd1, .esd2 = esd2,
           .lsd = lsd ))),
-  vfamily = c("mix2normal1"),
+  vfamily = c("mix2normal"),
   deriv = eval(substitute(expression({
     phi <- eta2theta(eta[, 1], link = .lphi, earg = .ephi)
     mu1 <- eta2theta(eta[, 2], link = .lmu,  earg = .emu1)
@@ -197,8 +209,8 @@ mix2normal1.control <- function(trace = TRUE, ...) {
     dmu2.deta <- dtheta.deta(mu2, link = .lmu, earg = .emu2)
     dsd1.deta <- dtheta.deta(sd1, link = .lsd, earg = .esd1)
     dsd2.deta <- dtheta.deta(sd2, link = .lsd, earg = .esd2)
-    f1 <- dnorm(y, mean=mu1, sd=sd1)
-    f2 <- dnorm(y, mean=mu2, sd=sd2)
+    f1 <- dnorm(y, mean = mu1, sd = sd1)
+    f2 <- dnorm(y, mean = mu2, sd = sd2)
     pdf <- phi*f1 + (1 - phi)*f2
     z1 <- (y-mu1) / sd1
     z2 <- (y-mu2) / sd2
@@ -222,12 +234,11 @@ mix2normal1.control <- function(trace = TRUE, ...) {
            .nsimEIM = nsimEIM ))),
   weight = eval(substitute(expression({
 
-    d3 <- deriv3(~ log(
-        phi * dnorm((ysim-mu1)/sd1) / sd1 +
-        (1 - phi) * dnorm((ysim-mu2)/sd2) / sd2),
-        c("phi","mu1","sd1","mu2","sd2"), hessian= TRUE)
+    d3 <- deriv3(~ log(     phi  * dnorm((ysim-mu1)/sd1) / sd1 +
+                       (1 - phi) * dnorm((ysim-mu2)/sd2) / sd2),
+        c("phi","mu1","sd1","mu2","sd2"), hessian = TRUE)
     run.mean <- 0
-    for(ii in 1:( .nsimEIM )) {
+    for (ii in 1:( .nsimEIM )) {
       ysim <- ifelse(runif(n) < phi, rnorm(n, mu1, sd1),
                                      rnorm(n, mu2, sd2))
 
@@ -236,9 +247,9 @@ mix2normal1.control <- function(trace = TRUE, ...) {
       rm(ysim)
 
       temp3 <- matrix(0, n, dimm(M))
-      for(ss in 1:M)
-          for(tt in ss:M)
-              temp3[,iam(ss,tt, M)] <-  -d2l.dthetas2[,ss,tt]
+      for (ss in 1:M)
+        for (tt in ss:M)
+          temp3[,iam(ss,tt, M)] <-  -d2l.dthetas2[, ss, tt]
 
       run.mean <- ((ii-1) * run.mean + temp3) / ii
     }
@@ -282,11 +293,11 @@ mix2poisson.control <- function(trace = TRUE, ...) {
 
 
 
-  if (!is.Numeric(qmu, allowable.length = 2, positive = TRUE) ||
+  if (!is.Numeric(qmu, length.arg = 2, positive = TRUE) ||
       any(qmu >= 1))
     stop("bad input for argument 'qmu'")
   if (length(iphi) &&
-     (!is.Numeric(iphi, allowable.length = 1, positive = TRUE) ||
+     (!is.Numeric(iphi, length.arg = 1, positive = TRUE) ||
      iphi >= 1))
     stop("bad input for argument 'iphi'")
   if (length(il1) && !is.Numeric(il1))
@@ -295,7 +306,7 @@ mix2poisson.control <- function(trace = TRUE, ...) {
     stop("bad input for argument 'il2'")
 
 
-  if (!is.Numeric(nsimEIM, allowable.length = 1,
+  if (!is.Numeric(nsimEIM, length.arg = 1,
                   integer.valued = TRUE) ||
       nsimEIM <= 10)
     stop("'nsimEIM' should be an integer greater than 10")
@@ -309,7 +320,7 @@ mix2poisson.control <- function(trace = TRUE, ...) {
             namesof("lambda2", llambda, earg = el2, tag = FALSE), "\n",
             "Mean:     phi*lambda1 + (1 - phi)*lambda2"),
   constraints = eval(substitute(expression({
-    constraints <- cm.zero.vgam(constraints, x, .zero, M)
+    constraints <- cm.zero.VGAM(constraints, x = x, .zero , M = M)
   }), list( .zero = zero ))),
   initialize = eval(substitute(expression({
 
@@ -336,14 +347,14 @@ mix2poisson.control <- function(trace = TRUE, ...) {
 
     if (!length(etastart)) {
       qy <- quantile(y, prob =  .qmu)
-      init.phi <-     rep(if(length(.iphi)) .iphi else 0.5, length = n)
-      init.lambda1 <- rep(if(length(.il1)) .il1 else qy[1], length = n)
-      init.lambda2 <- rep(if(length(.il2)) .il2 else qy[2], length = n)
+      init.phi <-     rep(if (length(.iphi)) .iphi else 0.5, length = n)
+      init.lambda1 <- rep(if (length(.il1)) .il1 else qy[1], length = n)
+      init.lambda2 <- rep(if (length(.il2)) .il2 else qy[2], length = n)
 
       if (!length(etastart))  
         etastart <- cbind(theta2eta(init.phi, .lphi , earg = .ephi ),
-                         theta2eta(init.lambda1, .llambda , earg = .el1 ),
-                         theta2eta(init.lambda2, .llambda , earg = .el2 ))
+                          theta2eta(init.lambda1, .llambda , earg = .el1 ),
+                          theta2eta(init.lambda2, .llambda , earg = .el2 ))
     }
   }), list(.lphi = lphi, .llambda = llambda,
            .ephi = ephi, .el1 = el1, .el2 = el2,
@@ -370,15 +381,24 @@ mix2poisson.control <- function(trace = TRUE, ...) {
            .ephi = ephi, .el1 = el1, .el2 = el2,
            .nsimEIM = nsimEIM ))),
   loglikelihood = eval(substitute(
-    function(mu,y,w,residuals = FALSE,eta,extra = NULL) {
+    function(mu, y, w, residuals = FALSE, eta,
+             extra = NULL,
+             summation = TRUE) {
     phi <- eta2theta(eta[, 1], link = .lphi, earg = .ephi)
     lambda1 <- eta2theta(eta[, 2], link = .llambda, earg = .el1)
     lambda2 <- eta2theta(eta[, 3], link = .llambda, earg = .el2)
     f1 <- dpois(y, lam = lambda1)
     f2 <- dpois(y, lam = lambda2)
-    if (residuals) stop("loglikelihood residuals not ",
-                        "implemented yet") else
-    sum(w * log(phi*f1 + (1 - phi)*f2))
+    if (residuals) {
+      stop("loglikelihood residuals not implemented yet")
+    } else {
+      ll.elts <- c(w) * log(phi*f1 + (1 - phi)*f2)
+      if (summation) {
+        sum(ll.elts)
+      } else {
+        ll.elts
+      }
+    }
   }, list(.lphi = lphi, .llambda = llambda,
            .ephi = ephi, .el1 = el1, .el2 = el2 ))),
   vfamily = c("mix2poisson"),
@@ -408,7 +428,7 @@ mix2poisson.control <- function(trace = TRUE, ...) {
            .nsimEIM = nsimEIM ))),
   weight = eval(substitute(expression({
     run.mean <- 0
-    for(ii in 1:( .nsimEIM )) {
+    for (ii in 1:( .nsimEIM )) {
       ysim <- ifelse(runif(n) < phi, rpois(n, lambda1),
                                     rpois(n, lambda2))
       f1 <- dpois(x = ysim, lam = lambda1)
@@ -472,6 +492,8 @@ mix2exp.control <- function(trace = TRUE, ...) {
   list(trace = trace)
 }
 
+
+
  mix2exp <- function(lphi = "logit", llambda = "loge",
                      iphi = 0.5, il1 = NULL, il2 = NULL,
                      qmu = c(0.8, 0.2), nsimEIM = 100, zero = 1) {
@@ -486,11 +508,11 @@ mix2exp.control <- function(trace = TRUE, ...) {
   el1 <- el2 <- elambda
 
 
-  if (!is.Numeric(qmu, allowable.length = 2, positive = TRUE) ||
+  if (!is.Numeric(qmu, length.arg = 2, positive = TRUE) ||
       any(qmu >= 1))
     stop("bad input for argument 'qmu'")
   if (length(iphi) &&
-     (!is.Numeric(iphi, allowable.length = 1, positive = TRUE) ||
+     (!is.Numeric(iphi, length.arg = 1, positive = TRUE) ||
       iphi >= 1))
     stop("bad input for argument 'iphi'")
   if (length(il1) && !is.Numeric(il1))
@@ -501,7 +523,7 @@ mix2exp.control <- function(trace = TRUE, ...) {
 
 
 
-  if (!is.Numeric(nsimEIM, allowable.length = 1, integer.valued = TRUE) ||
+  if (!is.Numeric(nsimEIM, length.arg = 1, integer.valued = TRUE) ||
       nsimEIM <= 10)
     stop("'nsimEIM' should be an integer greater than 10")
 
@@ -515,7 +537,7 @@ mix2exp.control <- function(trace = TRUE, ...) {
             "Mean:     phi / lambda1 + (1 - phi) / lambda2\n"),
 
   constraints = eval(substitute(expression({
-    constraints <- cm.zero.vgam(constraints, x, .zero, M)
+    constraints <- cm.zero.VGAM(constraints, x = x, .zero , M = M)
   }), list( .zero = zero ))),
 
   initialize = eval(substitute(expression({
@@ -541,9 +563,9 @@ mix2exp.control <- function(trace = TRUE, ...) {
 
     if (!length(etastart)) {
       qy <- quantile(y, prob =  .qmu)
-      init.phi <-     rep(if(length(.iphi)) .iphi else 0.5, length = n)
-      init.lambda1 <- rep(if(length(.il1)) .il1 else 1/qy[1], length = n)
-      init.lambda2 <- rep(if(length(.il2)) .il2 else 1/qy[2], length = n)
+      init.phi <-     rep(if (length(.iphi)) .iphi else 0.5, length = n)
+      init.lambda1 <- rep(if (length(.il1)) .il1 else 1/qy[1], length = n)
+      init.lambda2 <- rep(if (length(.il2)) .il2 else 1/qy[2], length = n)
       if (!length(etastart))  
         etastart <- cbind(theta2eta(init.phi,     .lphi,    earg = .ephi),
                           theta2eta(init.lambda1, .llambda, earg = .el1),
@@ -573,16 +595,25 @@ mix2exp.control <- function(trace = TRUE, ...) {
   }), list(.lphi = lphi, .llambda = llambda, .nsimEIM = nsimEIM,
            .ephi = ephi, .el1 = el1, .el2 = el2 ))),
   loglikelihood = eval(substitute(
-      function(mu,y,w,residuals = FALSE,eta,extra = NULL) {
+    function(mu, y, w, residuals = FALSE, eta,
+             extra = NULL,
+             summation = TRUE) {
     phi     <- eta2theta(eta[, 1], link = .lphi,    earg = .ephi)
     lambda1 <- eta2theta(eta[, 2], link = .llambda, earg = .el1)
     lambda2 <- eta2theta(eta[, 3], link = .llambda, earg = .el2)
 
     f1 <- dexp(y, rate=lambda1)
     f2 <- dexp(y, rate=lambda2)
-    if (residuals) stop("loglikelihood residuals not ",
-                        "implemented yet") else
-    sum(w * log(phi*f1 + (1 - phi)*f2))
+    if (residuals) {
+      stop("loglikelihood residuals not implemented yet")
+    } else {
+      ll.elts <- c(w) * log(phi*f1 + (1 - phi)*f2)
+      if (summation) {
+        sum(ll.elts)
+      } else {
+        ll.elts
+      }
+    }
   }, list(.lphi = lphi, .llambda = llambda,
           .ephi = ephi, .el1 = el1, .el2 = el2 ))),
   vfamily = c("mix2exp"),
@@ -611,7 +642,7 @@ mix2exp.control <- function(trace = TRUE, ...) {
            .ephi = ephi, .el1 = el1, .el2 = el2 ))),
   weight = eval(substitute(expression({
     run.mean <- 0
-    for(ii in 1:( .nsimEIM )) {
+    for (ii in 1:( .nsimEIM )) {
       ysim <- ifelse(runif(n) < phi, rexp(n, lambda1),
                                      rexp(n, lambda2))
       f1 <- dexp(x = ysim, rate=lambda1)
