@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2013 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2015 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -12,29 +12,29 @@
 
 
 
-vnonlinear.control <- function(save.weight = TRUE, ...) {
+vnonlinear.control <- function(save.weights = TRUE, ...) {
 
 
 
-    list(save.weight = as.logical(save.weight)[1])
+    list(save.weights = as.logical(save.weights)[1])
 }
 
 
 
 
-subset_lohi <- function(xvec, yvec,
+subset.lohi <- function(xvec, yvec,
                         probs.x = c(0.15, 0.85),
                         type = c("median", "wtmean", "unwtmean"),
                         wtvec = rep(1, len = length(xvec))) {
 
 
-  if (!is.Numeric(probs.x, allowable.length = 2))
+  if (!is.Numeric(probs.x, length.arg = 2))
     stop("argument 'probs.x' must be numeric and of length two")
 
   min.q <- quantile(xvec, probs = probs.x[1] )
   max.q <- quantile(xvec, probs = probs.x[2] )
 
-  if(mode(type) != "character" && mode(type) != "name")
+  if (mode(type) != "character" && mode(type) != "name")
     type <- as.character(substitute(type))
   type <- match.arg(type, c("median", "wtmean", "unwtmean"))[1]
 
@@ -71,8 +71,8 @@ subset_lohi <- function(xvec, yvec,
 
 
 
-micmen.control <- function(save.weight = TRUE, ...) {
-    list(save.weight = save.weight)
+micmen.control <- function(save.weights = TRUE, ...) {
+    list(save.weights = save.weights)
 }
 
 
@@ -83,7 +83,7 @@ micmen.control <- function(save.weight = TRUE, ...) {
                     init1 = NULL, init2 = NULL,
                     imethod = 1,
                     oim = TRUE,
-                    link1 = "identity", link2 = "identity",
+                    link1 = "identitylink", link2 = "identitylink",
                     firstDeriv = c("nsimEIM", "rpar"),
                     probs.x = c(0.15, 0.85),
                     nsimEIM = 500,
@@ -93,10 +93,10 @@ micmen.control <- function(save.weight = TRUE, ...) {
 
   firstDeriv <- match.arg(firstDeriv, c("nsimEIM", "rpar"))[1]
 
-  if (!is.Numeric(imethod, allowable.length = 1,
+  if (!is.Numeric(imethod, length.arg = 1,
                   integer.valued = TRUE, positive = TRUE))
     stop("argument 'imethod' must be integer")
-  if (!is.Numeric(probs.x, allowable.length = 2))
+  if (!is.Numeric(probs.x, length.arg = 2))
     stop("argument 'probs.x' must be numeric and of length two")
   if (!is.logical(oim) || length(oim) != 1)
     stop("argument 'oim' must be single logical")
@@ -104,7 +104,7 @@ micmen.control <- function(save.weight = TRUE, ...) {
     stopifnot(nsimEIM > 10, length(nsimEIM) == 1,
               nsimEIM == round(nsimEIM))
 
-  if (!is.Numeric(imethod, allowable.length = 1,
+  if (!is.Numeric(imethod, length.arg = 1,
                   integer.valued = TRUE, positive = TRUE) ||
      imethod > 3)
     stop("'imethod' must be 1 or 2 or 3")
@@ -131,7 +131,7 @@ micmen.control <- function(save.weight = TRUE, ...) {
             "Variance: constant"),
 
   constraints = eval(substitute(expression({
-    constraints <- cm.zero.vgam(constraints, x, .zero, M = 2)
+    constraints <- cm.zero.VGAM(constraints, x = x, .zero , M = 2)
   }), list( .zero = zero))),
 
   deviance = function(mu, y, w, residuals = FALSE, eta, extra = NULL) {
@@ -159,7 +159,7 @@ micmen.control <- function(save.weight = TRUE, ...) {
     if (ncol(as.matrix(Xm2)) != 1)
       stop("regressor not found or is not a vector. Use the ",
            "'form2' argument without an intercept")
-    Xm2 <- as.vector(Xm2) # Make sure
+    Xm2 <- as.vector(Xm2)  # Make sure
     extra$Xm2 <- Xm2          # Needed for @linkinv
 
     predictors.names <-
@@ -176,7 +176,7 @@ micmen.control <- function(save.weight = TRUE, ...) {
         init2 <- median(init1 * Xm2 / y - Xm2)
       }
       if ( .imethod == 1 || .imethod == 2) {
-        mysubset <- subset_lohi(Xm2, y, probs.x = .probs.x,
+        mysubset <- subset.lohi(Xm2, y, probs.x = .probs.x,
                   type = ifelse( .imethod == 1, "median", "wtmean"),
                   wtvec = w)
 
@@ -218,13 +218,13 @@ micmen.control <- function(save.weight = TRUE, ...) {
     misc$earg <- list(theta1 = .earg1 , theta2 = .earg2 )
 
     misc$rpar <- rpar
-    fit$df.residual <- n - rank   # Not nrow_X_vlm - rank
-    fit$df.total <- n             # Not nrow_X_vlm
+    fit$df.residual <- n - rank   # Not nrow.X.vlm - rank
+    fit$df.total <- n             # Not nrow.X.vlm
 
     extra$Xm2 <- NULL             # Regressor is in control$regressor 
     dpar <- .dispersion
     if (!dpar) {
-      dpar <- sum(c(w) * (y - mu)^2) / (n - ncol_X_vlm)
+      dpar <- sum(c(w) * (y - mu)^2) / (n - ncol.X.vlm)
     }
     misc$dispersion <- dpar
 
@@ -312,8 +312,8 @@ micmen.control <- function(save.weight = TRUE, ...) {
 
     if ( .firstDeriv == "rpar") {
       if (FALSE) {
-        wz <-  dmus.dthetas[,index$row] *  dmus.dthetas[,index$col] *
-               dthetas.detas[,index$row] * dthetas.detas[,index$col]
+        wz <-   dmus.dthetas[, index$row] *  dmus.dthetas[, index$col] *
+               dthetas.detas[, index$row] * dthetas.detas[, index$col]
         if (M > 1)
           wz[, 2:M] <- wz[, 2:M] + rpar
       } else {
@@ -356,15 +356,15 @@ micmen.control <- function(save.weight = TRUE, ...) {
 
 
 
-skira.control <- function(save.weight = TRUE, ...) {
-  list(save.weight = save.weight)
+skira.control <- function(save.weights = TRUE, ...) {
+  list(save.weights = save.weights)
 }
 
 
 
  skira <- function(rpar = 0.1, divisor = 10,
            init1 = NULL, init2 = NULL,
-           link1 = "identity", link2 = "identity",
+           link1 = "identitylink", link2 = "identitylink",
            earg1 = list(),
            earg2 = list(),
            imethod = 1,
@@ -377,7 +377,7 @@ skira.control <- function(save.weight = TRUE, ...) {
 
   firstDeriv <- match.arg(firstDeriv, c("nsimEIM", "rpar"))[1]
 
-  if (!is.Numeric(probs.x, allowable.length = 2))
+  if (!is.Numeric(probs.x, length.arg = 2))
     stop("argument 'probs.x' must be numeric and of length two")
 
   estimated.dispersion <- dispersion == 0
@@ -386,7 +386,7 @@ skira.control <- function(save.weight = TRUE, ...) {
   if (mode(link2) != "character" && mode(link2) != "name")
     link2 <- as.character(substitute(link2))
 
-  if (!is.Numeric(imethod, allowable.length = 1,
+  if (!is.Numeric(imethod, length.arg = 1,
                   integer.valued = TRUE, positive = TRUE))
     stop("argument 'imethod' must be integer")
 
@@ -409,14 +409,16 @@ skira.control <- function(save.weight = TRUE, ...) {
             namesof("theta1", link1, earg = earg1), ", ",
             namesof("theta2", link2, earg = earg2)),
   constraints = eval(substitute(expression({
-    constraints <- cm.zero.vgam(constraints, x, .zero, M = 2)
+    constraints <- cm.zero.VGAM(constraints, x = x, .zero , M = 2)
   }), list( .zero = zero ))),
   deviance = function(mu, y, w, residuals = FALSE, eta, extra = NULL) {
     M <- if (is.matrix(y))
       ncol(y) else 1
     if (residuals) {
       if (M > 1) NULL else (y - mu) * sqrt(w)
-    } else ResSS.vgam(y - mu, w, M = M)
+    } else {
+      ResSS.vgam(y - mu, w, M = M)
+    }
   },
   initialize = eval(substitute(expression({
 
@@ -453,7 +455,7 @@ skira.control <- function(save.weight = TRUE, ...) {
         max.q <- quantile(Xm2, probs = .probs.x[2] )
       if ( .imethod == 3 || .imethod == 2 ) {
 
-        mysubset <- subset_lohi(Xm2, y, probs.x = .probs.x,
+        mysubset <- subset.lohi(Xm2, y, probs.x = .probs.x,
                   type = ifelse( .imethod == 2, "median", "wtmean"),
                   wtvec = w)
 
@@ -486,8 +488,8 @@ skira.control <- function(save.weight = TRUE, ...) {
         fitted(smooth.spline(Xm2, y, w = w, df = 2.0))
       }
 
-      mysubset <- subset_lohi(Xm2, y, probs.x = .probs.x,
-                type = "wtmean", wtvec = w)
+      mysubset <- subset.lohi(Xm2, y, probs.x = .probs.x,
+                              type = "wtmean", wtvec = w)
 
 
       mat.x <- with(mysubset, cbind(c(1, 1),
@@ -543,7 +545,7 @@ skira.control <- function(save.weight = TRUE, ...) {
     fit$df.total <- n
     dpar <- .dispersion
     if (!dpar) {
-      dpar <- sum(c(w) * (y - mu)^2) / (n - ncol_X_vlm)
+      dpar <- sum(c(w) * (y - mu)^2) / (n - ncol.X.vlm)
     }
     misc$dispersion <- dpar
     misc$default.dispersion <- 0
@@ -624,7 +626,7 @@ skira.control <- function(save.weight = TRUE, ...) {
       mysigma <- sqrt( median( (y - mu)^2 ) ) / 100
       mysigma <- 1
 
-      for(ii in 1:( .nsimEIM )) {
+      for (ii in 1:( .nsimEIM )) {
         ysim <- 1 / (theta1 + theta2 * Xm2) + rnorm(n, sd = mysigma)
         temp3 <- (ysim - mu) * dmus.dthetas * dthetas.detas
         run.varcov <- run.varcov +
